diff

Function diff 

pub fn diff(
    from: &SyntaxNode<RustLanguage>,
    to: &SyntaxNode<RustLanguage>,
) -> TreeDiff
Finds a (potentially minimal) diff, which, applied to from, will result in to.

Specifically, returns a structure that consists of a replacements, insertions and deletions such that applying this map on from will result in to.

This function tries to find a fine-grained diff.