pub struct BlockExpr { /* private fields */ }Implementations
Sourceimpl BlockExpr
impl BlockExpr
pub fn modifier(&self) -> Option<BlockModifier>
Sourcepub fn is_standalone(&self) -> bool
pub fn is_standalone(&self) -> bool
false if the block is an intrinsic part of the syntax and can’t be replaced with arbitrary expression.
fn foo() { not_stand_alone }
const FOO: () = { stand_alone };Sourceimpl BlockExpr
impl BlockExpr
pub fn label(&self) -> Option<Label>
pub fn stmt_list(&self) -> Option<StmtList>
pub fn async_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn const_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn gen_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn move_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn try_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn unsafe_token(&self) -> Option<SyntaxToken<RustLanguage>>
Sourceimpl BlockExpr
impl BlockExpr
pub fn statements(&self) -> impl Iterator<Item = Stmt>
pub fn tail_expr(&self) -> Option<Expr>
Sourcepub fn may_carry_attributes(&self) -> bool
pub fn may_carry_attributes(&self) -> bool
Block expressions accept outer and inner attributes, but only when they are the outer expression of an expression statement or the final expression of another block expression.