pub struct RecordExprField { /* private fields */ }Implementations
Sourceimpl RecordExprField
impl RecordExprField
Sourcepub fn replace_expr(&self, expr: Expr)
pub fn replace_expr(&self, expr: Expr)
This will either replace the initializer, or in the case that this is a shorthand convert the initializer into the name ref and insert the expr as the new initializer.
Sourceimpl RecordExprField
impl RecordExprField
pub fn parent_record_lit(&self) -> RecordExpr
Sourceimpl RecordExprField
impl RecordExprField
pub fn expr(&self) -> Option<Expr>
pub fn name_ref(&self) -> Option<NameRef>
pub fn colon_token(&self) -> Option<SyntaxToken<RustLanguage>>
Sourceimpl RecordExprField
impl RecordExprField
pub fn for_field_name(field_name: &NameRef) -> Option<RecordExprField>
pub fn for_name_ref(name_ref: &NameRef) -> Option<RecordExprField>
Sourcepub fn field_name(&self) -> Option<NameRef>
pub fn field_name(&self) -> Option<NameRef>
Deals with field init shorthand