pub struct UseTree { /* private fields */ }Implementations
Sourceimpl UseTree
impl UseTree
Sourcepub fn remove_recursive(self)
pub fn remove_recursive(self)
Deletes the usetree node represented by the input. Recursively removes parents, including use nodes that become empty.
pub fn get_or_create_use_tree_list(&self) -> UseTreeList
Sourcepub fn split_prefix(&self, prefix: &Path)
pub fn split_prefix(&self, prefix: &Path)
Splits off the given prefix, making it the path component of the use tree, appending the rest of the path to all UseTreeList items.
Examples
prefix$0::suffix -> prefix::{suffix}
prefix$0 -> prefix::{self}
prefix$0::* -> prefix::{*}
Sourcepub fn wrap_in_tree_list(&self) -> Option<()>
pub fn wrap_in_tree_list(&self) -> Option<()>
Wraps the use tree in use tree list with no top level path (if it isn’t already).
Examples
foo::bar -> {foo::bar}
{foo::bar} -> {foo::bar}
Sourceimpl UseTree
impl UseTree
pub fn path(&self) -> Option<Path>
pub fn rename(&self) -> Option<Rename>
pub fn use_tree_list(&self) -> Option<UseTreeList>
pub fn star_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn coloncolon_token(&self) -> Option<SyntaxToken<RustLanguage>>
Sourceimpl UseTree
impl UseTree
pub fn is_simple_path(&self) -> bool
pub fn parent_use_tree_list(&self) -> Option<UseTreeList>
pub fn top_use_tree(&self) -> UseTree