Styles

Enum Styles 

pub enum Styles {
    Clear,
    Bold,
    Dimmed,
    Underline,
    Reversed,
    Italic,
    Blink,
    Hidden,
    Strikethrough,
}
Enum containing all of the available style settings that can be applied to a Styles and by extension, a colrized type.

Implementation of bitwise logical operators

The implementations of BitAnd, BitOr, BitXor, and Not are really extensions of Style’s implementations of the same. BitOr is great for starting chains of Styles’s for creating Style’s.

let my_styles =
    // BitOr<Styles> for Styles (Styles | Styles) = Style
    Styles::Bold | Styles::Underline
    // BitOr<Styles> for Style (Style | Styles) = Style
    | Styles::Italic;

for s in [Styles::Bold, Styles::Underline, Styles::Italic] {
    assert!(my_styles.contains(s));
}

Not has far fewer use cases but can still find use in turning a Styles into a Style with all styles activated except that Styles.

let everything_but_bold = !Styles::Bold;

assert!(everything_but_bold.contains(Styles::Underline));
assert!(everything_but_bold.contains(Styles::Strikethrough));
assert!(!everything_but_bold.contains(Styles::Bold));

Variants



Clear



Bold



Dimmed



Underline



Reversed



Italic



Hidden



Strikethrough