pub enum EventKind {
Any,
Access(AccessKind),
Create(CreateKind),
Modify(ModifyKind),
Remove(RemoveKind),
Other,
}Expand description
Top-level event kind.
This is arguably the most important classification for events. All subkinds below this one represent details that may or may not be available for any particular backend, but most tools and Notify systems will only care about which of these four general kinds an event is about.
Variants
Any
The catch-all event kind, for unsupported/unknown events.
This variant should be used as the “else” case when mapping native kernel bitmasks or bitmaps, such that if the mask is ever extended with new event types the backend will not gain bugs due to not matching new unknown event types.
This variant is also the default variant used when Notify is in “imprecise” mode.
Access(AccessKind)
An event describing non-mutating access operations on files.
This event is about opening and closing file handles, as well as executing files, and any other such event that is about accessing files, folders, or other structures rather than mutating them.
Only some platforms are capable of generating these.
Create(CreateKind)
An event describing creation operations on files.
This event is about the creation of files, folders, or other structures but not about e.g. writing new content into them.
Modify(ModifyKind)
An event describing mutation of content, name, or metadata.
This event is about the mutation of files’, folders’, or other structures’ content, name (path), or associated metadata (attributes).
Remove(RemoveKind)
An event describing removal operations on files.
This event is about the removal of files, folders, or other structures but not e.g. erasing content from them. This may also be triggered for renames/moves that move files out of the watched subpath.
Some editors also trigger Remove events when saving files as they may opt for removing (or renaming) the original then creating a new file in-place.
Other
An event not fitting in any of the above four categories.
This may be used for meta-events about the watch itself.
Implementations