pub enum Language {
Show 174 variants
Afrikaans,
Albanian,
Aleut,
Amharic,
Apache,
Arabic,
Armenian,
Assamese,
Aymara,
Azeri,
Bashkir,
Basque,
Belarusian,
Bengali,
Bosnian,
Breton,
Bulgarian,
Burmese,
Cebuano,
Chamorro,
Chechen,
Cherokee,
Choctaw,
Chuvash,
Corsican,
Croatian,
Czech,
Danish,
Dhivehi,
Dutch,
English,
Estonian,
Farsi,
Filipino,
Finnish,
French,
Galician,
Georgian,
German,
Greek,
Greenlandic,
Guarani,
Gujarati,
HaitianCreole,
Hausa,
Hawaiian,
Hebrew,
Hindi,
Hmong,
Hungarian,
Icelandic,
Igbo,
Ilocano,
Indonesian,
Inuit,
Italian,
Japanese,
Javanese,
Kannada,
Kazakh,
Khmer,
Korean,
Kurdish,
Kyrgyz,
Lao,
Latvian,
Lithuanian,
Luxembourgish,
Malagasy,
Malay,
Malayalam,
Maltese,
Mandarin,
Maori,
Marathi,
Mohawk,
Mongolian,
Nahuatl,
Navajo,
Nepali,
Norwegian,
Oriya,
Oromo,
Ossetian,
Pashto,
Polish,
Portuguese,
Punjabi,
Quechua,
RapaNui,
Romanian,
Russian,
Samoan,
ScottishGaelic,
Serbian,
Sindhi,
Sinhala,
Slovak,
Slovenian,
Somali,
Sotho,
Spanish,
Swahili,
Swedish,
Tagalog,
Tahitian,
Tajik,
Tamil,
Tatar,
Telugu,
Thai,
Tibetan,
Tswana,
Turkish,
Turkmen,
Tuvinian,
Uighur,
Ukrainian,
Urdu,
Uzbek,
Vietnamese,
Welsh,
Yakut,
Yoruba,
Zulu,
Berber,
Bislama,
Catalan,
Chichewa,
Comorian,
Dinka,
Dzongkha,
Fijian,
FrenchCreole,
Gilbertese,
Hakka,
HiriMotu,
IrishGaelic,
JamaicanCreole,
Kikongo,
Kinyarwanda,
Kirundi,
Kriol,
Latin,
Lingala,
Macedonian,
Marshallese,
MauritianCreole,
Nauruan,
Ndebele,
Nuer,
Palauan,
Pijin,
Romansh,
Sango,
SeychelloisCreole,
Shona,
Swati,
TaiwaneseHokkien,
Tetum,
Tigrinya,
TokPisin,
Tongan,
Tshiluba,
Tuvaluan,
VariousMayanIndigenous,
VariousMexicanIndigenous,
VariousBembaNyanjaLocal,
VariousIndianLocal,
VariousMicronesianLocal,
VariousRussianLocal,
VariousSouthAfricanLocal,
Xhosa,
Other(OtherLanguage),
}Expand description
Enumerates languages. This enum covers a wide range of languages, including major world languages, regional languages, and some languages with smaller populations for inclusivity.
Variants
Afrikaans
Albanian
Aleut
Amharic
Apache
Arabic
Armenian
Assamese
Aymara
Azeri
Bashkir
Basque
Belarusian
Bengali
Bosnian
Breton
Bulgarian
Burmese
Cebuano
Chamorro
Chechen
Cherokee
Choctaw
Chuvash
Corsican
Croatian
Czech
Danish
Dhivehi
Dutch
English
Estonian
Farsi
Filipino
Finnish
French
Galician
Georgian
German
Greek
Greenlandic
Guarani
Gujarati
HaitianCreole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Ilocano
Indonesian
Inuit
Italian
Japanese
Javanese
Kannada
Kazakh
Khmer
Korean
Kurdish
Kyrgyz
Lao
Latvian
Lithuanian
Luxembourgish
Malagasy
Malay
Malayalam
Maltese
Mandarin
Maori
Marathi
Mohawk
Mongolian
Nahuatl
Nepali
Norwegian
Oriya
Oromo
Ossetian
Pashto
Polish
Portuguese
Punjabi
Quechua
RapaNui
Romanian
Russian
Samoan
ScottishGaelic
Serbian
Sindhi
Sinhala
Slovak
Slovenian
Somali
Sotho
Spanish
Swahili
Swedish
Tagalog
Tahitian
Tajik
Tamil
Tatar
Telugu
Thai
Tibetan
Tswana
Turkish
Turkmen
Tuvinian
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Yakut
Yoruba
Zulu
Berber
Bislama
Catalan
Chichewa
Comorian
Dinka
Dzongkha
Fijian
FrenchCreole
Gilbertese
Hakka
HiriMotu
IrishGaelic
JamaicanCreole
Kikongo
Kinyarwanda
Kirundi
Kriol
Latin
Lingala
Macedonian
Marshallese
MauritianCreole
Nauruan
Ndebele
Nuer
Palauan
Pijin
Romansh
Sango
SeychelloisCreole
Shona
Swati
TaiwaneseHokkien
Tetum
Tigrinya
TokPisin
Tongan
Tshiluba
Tuvaluan
VariousMayanIndigenous
VariousMexicanIndigenous
VariousBembaNyanjaLocal
VariousIndianLocal
VariousMicronesianLocal
VariousRussianLocal
VariousSouthAfricanLocal
Xhosa
Other(OtherLanguage)
Implementations