TomlEditItem

Enum TomlEditItem 

pub enum TomlEditItem {
    None,
    Value(Value),
    Table(Table),
    ArrayOfTables(ArrayOfTables),
}
Type representing either a value, a table, an array of tables, or none.

Variants



None

Type representing none.



Value(Value)

Type representing value.



Table(Table)

Type representing table.



ArrayOfTables(ArrayOfTables)

Type representing array of tables.

Implementations

Source

impl Item

pub fn or_insert(&mut self, item: Item) -> &mut Item

Sets self to the given item if self is none and returns a mutable reference to self.

Source

impl Item

Downcasting

pub fn type_name(&self) -> &'static str

Text description of value type

pub fn get<I>(&self, index: I) -> Option<&Item>
where I: Index,

Index into a TOML array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.

Returns None if:

  • The type of self does not match the type of the index, for example if the index is a string and self is an array or a number.
  • The given key does not exist in the map or the given index is not within the bounds of the array.
pub fn get_mut<I>(&mut self, index: I) -> Option<&mut Item>
where I: Index,

Mutably index into a TOML array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.

Returns None if:

  • The type of self does not match the type of the index, for example if the index is a string and self is an array or a number.
  • The given key does not exist in the map or the given index is not within the bounds of the array.
pub fn as_value(&self) -> Option<&Value>

Casts self to Value

pub fn as_table(&self) -> Option<&Table>

Casts self to Table

To operate on both Tables and InlineTables, see Item::as_table_like

pub fn as_array_of_tables(&self) -> Option<&ArrayOfTables>

Casts self to ArrayOfTables

pub fn as_value_mut(&mut self) -> Option<&mut Value>

Casts self to mutable Value.

pub fn as_table_mut(&mut self) -> Option<&mut Table>

Casts self to mutable Table

To operate on both Tables and InlineTables, see Item::as_table_like_mut

pub fn as_array_of_tables_mut(&mut self) -> Option<&mut ArrayOfTables>

Casts self to mutable ArrayOfTables

pub fn into_value(self) -> Result<Value, Item>

Casts self to Value

pub fn make_value(&mut self)

In-place convert to a value

pub fn into_table(self) -> Result<Table, Item>

Casts self to Table

This does not include InlineTables

pub fn into_array_of_tables(self) -> Result<ArrayOfTables, Item>

Casts self to ArrayOfTables

pub fn is_value(&self) -> bool

Returns true if self is a Value

pub fn is_table(&self) -> bool

Returns true if self is a Table

To operate on both Tables and InlineTables, see Item::is_table_like

pub fn is_array_of_tables(&self) -> bool

Returns true if self is an ArrayOfTables

pub fn is_none(&self) -> bool

Returns true if self is None.

pub fn as_integer(&self) -> Option<i64>

Casts self to integer.

pub fn is_integer(&self) -> bool

Returns true if self is an integer.

pub fn as_float(&self) -> Option<f64>

Casts self to float.

pub fn is_float(&self) -> bool

Returns true if self is a float.

pub fn as_bool(&self) -> Option<bool>

Casts self to boolean.

pub fn is_bool(&self) -> bool

Returns true if self is a boolean.

pub fn as_str(&self) -> Option<&str>

Casts self to str.

pub fn is_str(&self) -> bool

Returns true if self is a string.

pub fn as_datetime(&self) -> Option<&Datetime>

Casts self to date-time.

pub fn is_datetime(&self) -> bool

Returns true if self is a date-time.

pub fn as_array(&self) -> Option<&Array>

Casts self to array.

pub fn as_array_mut(&mut self) -> Option<&mut Array>

Casts self to mutable array.

pub fn is_array(&self) -> bool

Returns true if self is an array.

pub fn as_inline_table(&self) -> Option<&InlineTable>

Casts self to inline table.

pub fn as_inline_table_mut(&mut self) -> Option<&mut InlineTable>

Casts self to mutable inline table.

pub fn is_inline_table(&self) -> bool

Returns true if self is an inline table.

pub fn as_table_like(&self) -> Option<&dyn TableLike>

Casts self to either a table or an inline table.

pub fn as_table_like_mut(&mut self) -> Option<&mut dyn TableLike>

Casts self to either a table or an inline table.

pub fn is_table_like(&self) -> bool

Returns true if self is either a table, or an inline table.

pub fn span(&self) -> Option<Range<usize>>

The location within the original document

This generally requires an ImDocument.