#[non_exhaustive]pub struct Dependency {
pub name: String,
pub source: Option<String>,
pub req: VersionReq,
pub kind: DependencyKind,
pub optional: bool,
pub uses_default_features: bool,
pub features: Vec<String>,
pub target: Option<Platform>,
pub rename: Option<String>,
pub registry: Option<String>,
pub path: Option<Utf8PathBuf>,
}Expand description
A dependency of the main crate
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName as given in the Cargo.toml
source: Option<String>The source of dependency
req: VersionReqThe required version
kind: DependencyKindThe kind of dependency this is
optional: boolWhether this dependency is required or optional
uses_default_features: boolWhether the default features in this dependency are used.
features: Vec<String>The list of features enabled for this dependency.
target: Option<Platform>The target this dependency is specific to.
Use the Display trait to access the contents.
rename: Option<String>If the dependency is renamed, this is the new name for the dependency as a string. None if it is not renamed.
registry: Option<String>The URL of the index of the registry where this dependency is from.
If None, the dependency is from crates.io.
path: Option<Utf8PathBuf>The file system path for a local path dependency.
Only produced on cargo 1.51+