pub struct ReceiverStream<T> { /* private fields */ }Expand description
A wrapper around tokio::sync::mpsc::Receiver that implements Stream.
Implementations
Sourceimpl<T> ReceiverStream<T>
impl<T> ReceiverStream<T>
Sourcepub fn new(recv: Receiver<T>) -> ReceiverStream<T>
pub fn new(recv: Receiver<T>) -> ReceiverStream<T>
Create a new ReceiverStream.
Sourcepub fn into_inner(self) -> Receiver<T>
pub fn into_inner(self) -> Receiver<T>
Get back the inner Receiver.
Sourcepub fn close(&mut self)
pub fn close(&mut self)
Closes the receiving half of a channel without dropping it.
This prevents any further messages from being sent on the channel while
still enabling the receiver to drain messages that are buffered. Any
outstanding Permit values will still be able to send messages.
To guarantee no messages are dropped, after calling close(), you must
receive all items from the stream until None is returned.