pub struct TextSize { /* private fields */ }Expand description
A measure of text length. Also, equivalently, an index into text.
This is a UTF-8 bytes offset stored as u32, but
most clients should treat it as an opaque measure.
For cases that need to escape TextSize and return to working directly
with primitive integers, TextSize can be converted losslessly to/from
u32 via From conversions as well as losslessly be converted Into
usize. The usize -> TextSize direction can be done via TryFrom.
These escape hatches are primarily required for unit testing and when converting from UTF-8 size to another coordinate space, such as UTF-16.
Implementations
Sourceimpl TextSize
impl TextSize
Sourcepub fn of<T>(text: T) -> TextSizewhere
T: TextLen,
pub fn of<T>(text: T) -> TextSizewhere
T: TextLen,
The text size of some primitive text-like object.
Accepts char, &str, and &String.
Examples
let char_size = TextSize::of('🦀');
assert_eq!(char_size, TextSize::from(4));
let str_size = TextSize::of("rust-analyzer");
assert_eq!(str_size, TextSize::from(13));Sourceimpl TextSize
Methods to act like a primitive integer type, where reasonably applicable.
impl TextSize
Methods to act like a primitive integer type, where reasonably applicable.
Sourcepub const fn checked_add(self, rhs: TextSize) -> Option<TextSize>
pub const fn checked_add(self, rhs: TextSize) -> Option<TextSize>
Checked addition. Returns None if overflow occurred.
Sourcepub const fn checked_sub(self, rhs: TextSize) -> Option<TextSize>
pub const fn checked_sub(self, rhs: TextSize) -> Option<TextSize>
Checked subtraction. Returns None if overflow occurred.