AxisDescription

Trait AxisDescription 

pub trait AxisDescription {
    // Required method
    fn axis_description(&self) -> Cow<'_, str>;
}
A trait that describes the axis in textual form. Implementations usually associate a descriptive string per enum variant, used for instructing the end user or prompting an LLM how to expand that axis.

Required Methods

fn axis_description(&self) -> Cow<'_, str>

Returns the descriptive prompt or instructions for the axis.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors