AxisName

Trait AxisName 

pub trait AxisName {
    // Required method
    fn axis_name(&self) -> Cow<'_, str>;
}
A trait that describes the name of an axis. Implementations usually associate one distinct axis name string per enum variant.

Required Methods

fn axis_name(&self) -> Cow<'_, str>

Returns the short identifier used to represent the axis programmatically.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors