ClipboardProvider

Trait ClipboardProvider 

pub trait ClipboardProvider: Send {
    // Required methods
    fn get_contents(&mut self) -> Result<String, Box<dyn Error + Sync + Send>>;
    fn set_contents(
        &mut self,
        _: String,
    ) -> Result<(), Box<dyn Error + Sync + Send>>;
}
Trait for clipboard access

Required Methods

fn get_contents(&mut self) -> Result<String, Box<dyn Error + Sync + Send>>

Method to get the clipboard contents as a String

fn set_contents( &mut self, _: String, ) -> Result<(), Box<dyn Error + Sync + Send>>

Method to set the clipboard contents as a String

Implementors