SystemMessageGoal

Trait SystemMessageGoal 

pub trait SystemMessageGoal {
    // Required method
    fn system_message_goal(&self) -> Cow<'_, str>;
}
A trait that describes the system message goal for a given axis set. This is typically implemented for the entire enum and returns a single, static system message goal string for the entire type.

Required Methods

fn system_message_goal(&self) -> Cow<'_, str>

Returns the system message goal associated with the entire enum.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors