pub trait TokenExpansionAxis:
AxisName
+ AxisDescription
+ Debug
+ Send
+ Sync { }Expand description
Trait defining the capabilities of a TokenExpansionAxis.
We use these to determine a direction along which we can expand our knowledge of a given token.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".