pub enum Cow<'a, B>{
Borrowed(&'a B),
Owned(<B as ToOwned>::Owned),
}Expand description
A clone-on-write smart pointer.
The type Cow is a smart pointer providing clone-on-write functionality: it
can enclose and provide immutable access to borrowed data, and clone the
data lazily when mutation or ownership is required. The type is designed to
work with general borrowed data via the Borrow trait.
Cow implements Deref, which means that you can call
non-mutating methods directly on the data it encloses. If mutation
is desired, to_mut will obtain a mutable reference to an owned
value, cloning if necessary.
If you need reference-counting pointers, note that
Rc::make_mut and
Arc::make_mut can provide clone-on-write
functionality as well.
Examples
use std::borrow::Cow;
fn abs_all(input: &mut Cow<'_, [i32]>) {
for i in 0..input.len() {
let v = input[i];
if v < 0 {
// Clones into a vector if not already owned.
input.to_mut()[i] = -v;
}
}
}
// No clone occurs because `input` doesn't need to be mutated.
let slice = [0, 1, 2];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// Clone occurs because `input` needs to be mutated.
let slice = [-1, 0, 1];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// No clone occurs because `input` is already owned.
let mut input = Cow::from(vec![-1, 0, 1]);
abs_all(&mut input);Another example showing how to keep Cow in a struct:
use std::borrow::Cow;
struct Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
values: Cow<'a, [X]>,
}
impl<'a, X: Clone + 'a> Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
fn new(v: Cow<'a, [X]>) -> Self {
Items { values: v }
}
}
// Creates a container from borrowed values of a slice
let readonly = [1, 2];
let borrowed = Items::new((&readonly[..]).into());
match borrowed {
Items { values: Cow::Borrowed(b) } => println!("borrowed {b:?}"),
_ => panic!("expect borrowed value"),
}
let mut clone_on_write = borrowed;
// Mutates the data from slice into owned vec and pushes a new value on top
clone_on_write.values.to_mut().push(3);
println!("clone_on_write = {:?}", clone_on_write.values);
// The data was mutated. Let's check it out.
match clone_on_write {
Items { values: Cow::Owned(_) } => println!("clone_on_write contains owned data"),
_ => panic!("expect owned data"),
}Variants
Implementations
Sourceimpl<B> Cow<'_, B>
impl<B> Cow<'_, B>
Sourcepub const fn is_borrowed(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_borrowed(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is borrowed, i.e. if to_mut would require additional work.
Note: this is an associated function, which means that you have to call
it as Cow::is_borrowed(&c) instead of c.is_borrowed(). This is so
that there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow = Cow::Borrowed("moo");
assert!(Cow::is_borrowed(&cow));
let bull: Cow<'_, str> = Cow::Owned("...moo?".to_string());
assert!(!Cow::is_borrowed(&bull));Sourcepub const fn is_owned(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_owned(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is owned, i.e. if to_mut would be a no-op.
Note: this is an associated function, which means that you have to call
it as Cow::is_owned(&c) instead of c.is_owned(). This is so that
there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow: Cow<'_, str> = Cow::Owned("moo".to_string());
assert!(Cow::is_owned(&cow));
let bull = Cow::Borrowed("...moo?");
assert!(!Cow::is_owned(&bull));1.0.0 · Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);1.0.0 · Sourcepub fn into_owned(self) -> <B as ToOwned>::Owned
pub fn into_owned(self) -> <B as ToOwned>::Owned
Extracts the owned data.
Clones the data if it is not already owned.
Examples
Calling into_owned on a Cow::Borrowed returns a clone of the borrowed data:
use std::borrow::Cow;
let s = "Hello world!";
let cow = Cow::Borrowed(s);
assert_eq!(
cow.into_owned(),
String::from(s)
);Calling into_owned on a Cow::Owned returns the owned data. The data is moved out of the
Cow without being cloned.
use std::borrow::Cow;
let s = "Hello world!";
let cow: Cow<'_, str> = Cow::Owned(String::from(s));
assert_eq!(
cow.into_owned(),
String::from(s)
);Trait Implementations
1.14.0 · Sourceimpl<'a> AddAssign<&'a str> for Cow<'a, str>
impl<'a> AddAssign<&'a str> for Cow<'a, str>
Sourcefn add_assign(&mut self, rhs: &'a str)
fn add_assign(&mut self, rhs: &'a str)
+= operation. Read moreSourceimpl<'a> Arg for Cow<'a, CStr>
impl<'a> Arg for Cow<'a, CStr>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, CStr>
impl<'a> Arg for Cow<'a, CStr>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, OsStr>
impl<'a> Arg for Cow<'a, OsStr>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, OsStr>
impl<'a> Arg for Cow<'a, OsStr>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, str>
impl<'a> Arg for Cow<'a, str>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, str>
impl<'a> Arg for Cow<'a, str>
Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<C> Connection for Cow<'_, C>
impl<C> Connection for Cow<'_, C>
Sourcefn wait_for_event(&self) -> Result<Event, ConnectionError>
fn wait_for_event(&self) -> Result<Event, ConnectionError>
Sourcefn wait_for_raw_event(
&self,
) -> Result<<Cow<'_, C> as RequestConnection>::Buf, ConnectionError>
fn wait_for_raw_event( &self, ) -> Result<<Cow<'_, C> as RequestConnection>::Buf, ConnectionError>
Sourcefn wait_for_event_with_sequence(&self) -> Result<(Event, u64), ConnectionError>
fn wait_for_event_with_sequence(&self) -> Result<(Event, u64), ConnectionError>
Sourcefn wait_for_raw_event_with_sequence(
&self,
) -> Result<(<Cow<'_, C> as RequestConnection>::Buf, u64), ConnectionError>
fn wait_for_raw_event_with_sequence( &self, ) -> Result<(<Cow<'_, C> as RequestConnection>::Buf, u64), ConnectionError>
Sourcefn poll_for_event(&self) -> Result<Option<Event>, ConnectionError>
fn poll_for_event(&self) -> Result<Option<Event>, ConnectionError>
Sourcefn poll_for_raw_event(
&self,
) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
fn poll_for_raw_event( &self, ) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
Sourcefn poll_for_event_with_sequence(
&self,
) -> Result<Option<(Event, u64)>, ConnectionError>
fn poll_for_event_with_sequence( &self, ) -> Result<Option<(Event, u64)>, ConnectionError>
Sourcefn poll_for_raw_event_with_sequence(
&self,
) -> Result<Option<(<Cow<'_, C> as RequestConnection>::Buf, u64)>, ConnectionError>
fn poll_for_raw_event_with_sequence( &self, ) -> Result<Option<(<Cow<'_, C> as RequestConnection>::Buf, u64)>, ConnectionError>
Sourcefn flush(&self) -> Result<(), ConnectionError>
fn flush(&self) -> Result<(), ConnectionError>
Sourcefn generate_id(&self) -> Result<u32, ReplyOrIdError>
fn generate_id(&self) -> Result<u32, ReplyOrIdError>
Sourceimpl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
impl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<T> EncodeAsVarULE<T> for Cow<'_, T>
impl<T> EncodeAsVarULE<T> for Cow<'_, T>
Sourcefn encode_var_ule_as_slices<R>(&self, cb: impl FnOnce(&[&[u8]]) -> R) -> R
fn encode_var_ule_as_slices<R>(&self, cb: impl FnOnce(&[&[u8]]) -> R) -> R
cb with a piecewise list of byte slices that when concatenated
produce the memory pattern of the corresponding instance of T. Read moreSourcefn encode_var_ule_len(&self) -> usize
fn encode_var_ule_len(&self) -> usize
VarULE typeSourcefn encode_var_ule_write(&self, dst: &mut [u8])
fn encode_var_ule_write(&self, dst: &mut [u8])
VarULE type to the dst buffer. dst should
be the size of Self::encode_var_ule_len()1.19.0 · Sourceimpl<'a> Extend<Cow<'a, str>> for String
impl<'a> Extend<Cow<'a, str>> for String
Sourcefn extend<I>(&mut self, iter: I)
fn extend<I>(&mut self, iter: I)
Sourcefn extend_one(&mut self, s: Cow<'a, str>)
fn extend_one(&mut self, s: Cow<'a, str>)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl<'a, S> From<&'a RiAbsoluteStr<S>> for Cow<'a, RiAbsoluteStr<S>>where
S: Spec,
impl<'a, S> From<&'a RiAbsoluteStr<S>> for Cow<'a, RiAbsoluteStr<S>>where
S: Spec,
Sourcefn from(s: &'a RiAbsoluteStr<S>) -> Cow<'a, RiAbsoluteStr<S>>
fn from(s: &'a RiAbsoluteStr<S>) -> Cow<'a, RiAbsoluteStr<S>>
Sourceimpl<'a, S> From<&'a RiFragmentStr<S>> for Cow<'a, RiFragmentStr<S>>where
S: Spec,
impl<'a, S> From<&'a RiFragmentStr<S>> for Cow<'a, RiFragmentStr<S>>where
S: Spec,
Sourcefn from(s: &'a RiFragmentStr<S>) -> Cow<'a, RiFragmentStr<S>>
fn from(s: &'a RiFragmentStr<S>) -> Cow<'a, RiFragmentStr<S>>
Sourceimpl<'a, S> From<&'a RiQueryStr<S>> for Cow<'a, RiQueryStr<S>>where
S: Spec,
impl<'a, S> From<&'a RiQueryStr<S>> for Cow<'a, RiQueryStr<S>>where
S: Spec,
Sourcefn from(s: &'a RiQueryStr<S>) -> Cow<'a, RiQueryStr<S>>
fn from(s: &'a RiQueryStr<S>) -> Cow<'a, RiQueryStr<S>>
Sourceimpl<'a, S> From<&'a RiReferenceStr<S>> for Cow<'a, RiReferenceStr<S>>where
S: Spec,
impl<'a, S> From<&'a RiReferenceStr<S>> for Cow<'a, RiReferenceStr<S>>where
S: Spec,
Sourcefn from(s: &'a RiReferenceStr<S>) -> Cow<'a, RiReferenceStr<S>>
fn from(s: &'a RiReferenceStr<S>) -> Cow<'a, RiReferenceStr<S>>
Sourceimpl<'a, S> From<&'a RiRelativeStr<S>> for Cow<'a, RiRelativeStr<S>>where
S: Spec,
impl<'a, S> From<&'a RiRelativeStr<S>> for Cow<'a, RiRelativeStr<S>>where
S: Spec,
Sourcefn from(s: &'a RiRelativeStr<S>) -> Cow<'a, RiRelativeStr<S>>
fn from(s: &'a RiRelativeStr<S>) -> Cow<'a, RiRelativeStr<S>>
Sourceimpl<'a> From<&'a UriTemplateStr> for Cow<'a, UriTemplateStr>
impl<'a> From<&'a UriTemplateStr> for Cow<'a, UriTemplateStr>
Sourcefn from(s: &'a UriTemplateStr) -> Cow<'a, UriTemplateStr>
fn from(s: &'a UriTemplateStr) -> Cow<'a, UriTemplateStr>
Sourceimpl From<Cow<'_, GreenNodeData>> for NodeOrToken<GreenNode, GreenToken>
impl From<Cow<'_, GreenNodeData>> for NodeOrToken<GreenNode, GreenToken>
Sourcefn from(cow: Cow<'_, GreenNodeData>) -> NodeOrToken<GreenNode, GreenToken>
fn from(cow: Cow<'_, GreenNodeData>) -> NodeOrToken<GreenNode, GreenToken>
1.14.0 · Sourceimpl<'a, T> From<Cow<'a, [T]>> for Vec<T>
impl<'a, T> From<Cow<'a, [T]>> for Vec<T>
Sourcefn from(s: Cow<'a, [T]>) -> Vec<T>
fn from(s: Cow<'a, [T]>) -> Vec<T>
Converts a clone-on-write slice into a vector.
If s already owns a Vec<T>, it will be returned directly.
If s is borrowing a slice, a new Vec<T> will be allocated and
filled by cloning s’s items into it.
Examples
let o: Cow<'_, [i32]> = Cow::Owned(vec![1, 2, 3]);
let b: Cow<'_, [i32]> = Cow::Borrowed(&[1, 2, 3]);
assert_eq!(Vec::from(o), Vec::from(b));1.14.0 · Sourceimpl<'a> From<Cow<'a, str>> for String
impl<'a> From<Cow<'a, str>> for String
Sourcefn from(s: Cow<'a, str>) -> String
fn from(s: Cow<'a, str>) -> String
Converts a clone-on-write string to an owned
instance of String.
This extracts the owned string, clones the string if it is not already owned.
Example
// If the string is not owned...
let cow: Cow<'_, str> = Cow::Borrowed("eggplant");
// It will allocate on the heap and copy the string.
let owned: String = String::from(cow);
assert_eq!(&owned[..], "eggplant");Sourceimpl<'a> From<Cow<'a, str>> for Value
impl<'a> From<Cow<'a, str>> for Value
Sourcefn from(f: Cow<'a, str>) -> Value
fn from(f: Cow<'a, str>) -> Value
Convert copy-on-write string to Value::String.
Examples
use serde_json::Value;
use std::borrow::Cow;
let s: Cow<str> = Cow::Borrowed("lorem");
let x: Value = s.into();use serde_json::Value;
use std::borrow::Cow;
let s: Cow<str> = Cow::Owned("lorem".to_owned());
let x: Value = s.into();Sourceimpl<'a, S> From<RiAbsoluteString<S>> for Cow<'a, RiAbsoluteStr<S>>where
S: Spec,
impl<'a, S> From<RiAbsoluteString<S>> for Cow<'a, RiAbsoluteStr<S>>where
S: Spec,
Sourcefn from(s: RiAbsoluteString<S>) -> Cow<'a, RiAbsoluteStr<S>>
fn from(s: RiAbsoluteString<S>) -> Cow<'a, RiAbsoluteStr<S>>
Sourceimpl<'a, S> From<RiFragmentString<S>> for Cow<'a, RiFragmentStr<S>>where
S: Spec,
impl<'a, S> From<RiFragmentString<S>> for Cow<'a, RiFragmentStr<S>>where
S: Spec,
Sourcefn from(s: RiFragmentString<S>) -> Cow<'a, RiFragmentStr<S>>
fn from(s: RiFragmentString<S>) -> Cow<'a, RiFragmentStr<S>>
Sourceimpl<'a, S> From<RiQueryString<S>> for Cow<'a, RiQueryStr<S>>where
S: Spec,
impl<'a, S> From<RiQueryString<S>> for Cow<'a, RiQueryStr<S>>where
S: Spec,
Sourcefn from(s: RiQueryString<S>) -> Cow<'a, RiQueryStr<S>>
fn from(s: RiQueryString<S>) -> Cow<'a, RiQueryStr<S>>
Sourceimpl<'a, S> From<RiReferenceString<S>> for Cow<'a, RiReferenceStr<S>>where
S: Spec,
impl<'a, S> From<RiReferenceString<S>> for Cow<'a, RiReferenceStr<S>>where
S: Spec,
Sourcefn from(s: RiReferenceString<S>) -> Cow<'a, RiReferenceStr<S>>
fn from(s: RiReferenceString<S>) -> Cow<'a, RiReferenceStr<S>>
Sourceimpl<'a, S> From<RiRelativeString<S>> for Cow<'a, RiRelativeStr<S>>where
S: Spec,
impl<'a, S> From<RiRelativeString<S>> for Cow<'a, RiRelativeStr<S>>where
S: Spec,
Sourcefn from(s: RiRelativeString<S>) -> Cow<'a, RiRelativeStr<S>>
fn from(s: RiRelativeString<S>) -> Cow<'a, RiRelativeStr<S>>
Sourceimpl<'a> From<UriTemplateString> for Cow<'a, UriTemplateStr>
impl<'a> From<UriTemplateString> for Cow<'a, UriTemplateStr>
Sourcefn from(s: UriTemplateString) -> Cow<'a, UriTemplateStr>
fn from(s: UriTemplateString) -> Cow<'a, UriTemplateStr>
Sourceimpl<'r> FromData<'r> for Cow<'_, str>
impl<'r> FromData<'r> for Cow<'_, str>
Sourcetype Error = <Capped<Cow<'_, str>> as FromData<'r>>::Error
type Error = <Capped<Cow<'_, str>> as FromData<'r>>::Error
Sourcefn from_data<'life0, 'async_trait>(
r: &'r Request<'life0>,
d: Data<'r>,
) -> Pin<Box<dyn Future<Output = Outcome<Cow<'_, str>, (Status, <Cow<'_, str> as FromData<'r>>::Error), (Data<'r>, Status)>> + Send + 'async_trait>>
fn from_data<'life0, 'async_trait>( r: &'r Request<'life0>, d: Data<'r>, ) -> Pin<Box<dyn Future<Output = Outcome<Cow<'_, str>, (Status, <Cow<'_, str> as FromData<'r>>::Error), (Data<'r>, Status)>> + Send + 'async_trait>>
Self
from the incoming request body data. Read moreSourceimpl<'v> FromFormField<'v> for Cow<'v, str>
impl<'v> FromFormField<'v> for Cow<'v, str>
Sourceimpl<'x, 'a, P> FromUriParam<P, &'x Cow<'a, str>> for Cow<'a, str>where
P: Part,
impl<'x, 'a, P> FromUriParam<P, &'x Cow<'a, str>> for Cow<'a, str>where
P: Part,
Sourcefn from_uri_param(param: &'x Cow<'a, str>) -> &'x Cow<'a, str>
fn from_uri_param(param: &'x Cow<'a, str>) -> &'x Cow<'a, str>
T into a value of type Self::Target. The
resulting value of type Self::Target will be rendered into a URI using
its UriDisplay implementation.Sourceimpl<'x, 'a, P> FromUriParam<P, &'x mut Cow<'a, str>> for Cow<'a, str>where
P: Part,
impl<'x, 'a, P> FromUriParam<P, &'x mut Cow<'a, str>> for Cow<'a, str>where
P: Part,
Sourcefn from_uri_param(param: &'x mut Cow<'a, str>) -> &'x mut Cow<'a, str>
fn from_uri_param(param: &'x mut Cow<'a, str>) -> &'x mut Cow<'a, str>
T into a value of type Self::Target. The
resulting value of type Self::Target will be rendered into a URI using
its UriDisplay implementation.Sourceimpl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
impl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
Sourcetype Deserializer = CowStrDeserializer<'a, E>
type Deserializer = CowStrDeserializer<'a, E>
Sourcefn into_deserializer(self) -> CowStrDeserializer<'a, E>
fn into_deserializer(self) -> CowStrDeserializer<'a, E>
1.0.0 · Sourceimpl<B> Ord for Cow<'_, B>
impl<B> Ord for Cow<'_, B>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<S, T> PartialEq<&RiAbsoluteStr<S>> for Cow<'_, RiAbsoluteStr<T>>
impl<S, T> PartialEq<&RiAbsoluteStr<S>> for Cow<'_, RiAbsoluteStr<T>>
Sourceimpl<S, T> PartialEq<&RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<&RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<&RiFragmentStr<S>> for Cow<'_, RiFragmentStr<T>>
impl<S, T> PartialEq<&RiFragmentStr<S>> for Cow<'_, RiFragmentStr<T>>
Sourceimpl<S, T> PartialEq<&RiQueryStr<S>> for Cow<'_, RiQueryStr<T>>
impl<S, T> PartialEq<&RiQueryStr<S>> for Cow<'_, RiQueryStr<T>>
Sourceimpl<S, T> PartialEq<&RiReferenceStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<&RiReferenceStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<&RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialEq<&RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialEq<&RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialEq<&RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialEq<&RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<&RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<&RiRelativeStr<S>> for Cow<'_, RiRelativeStr<T>>
impl<S, T> PartialEq<&RiRelativeStr<S>> for Cow<'_, RiRelativeStr<T>>
Sourceimpl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<S>>> for &RiReferenceStr<T>
impl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<S>>> for &RiReferenceStr<T>
Sourceimpl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<S>>> for RiReferenceStr<T>
impl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<S>>> for RiReferenceStr<T>
Sourceimpl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<T>>> for &RiAbsoluteStr<S>
impl<S, T> PartialEq<Cow<'_, RiAbsoluteStr<T>>> for &RiAbsoluteStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiFragmentStr<T>>> for &RiFragmentStr<S>
impl<S, T> PartialEq<Cow<'_, RiFragmentStr<T>>> for &RiFragmentStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiQueryStr<T>>> for &RiQueryStr<S>
impl<S, T> PartialEq<Cow<'_, RiQueryStr<T>>> for &RiQueryStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiAbsoluteStr<S>
impl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiAbsoluteStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiReferenceStr<S>
impl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiReferenceStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiRelativeStr<S>
impl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for &RiRelativeStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for RiAbsoluteStr<S>
impl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for RiAbsoluteStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for RiRelativeStr<S>
impl<S, T> PartialEq<Cow<'_, RiReferenceStr<T>>> for RiRelativeStr<S>
Sourceimpl<S, T> PartialEq<Cow<'_, RiRelativeStr<S>>> for &RiReferenceStr<T>
impl<S, T> PartialEq<Cow<'_, RiRelativeStr<S>>> for &RiReferenceStr<T>
Sourceimpl<S, T> PartialEq<Cow<'_, RiRelativeStr<S>>> for RiReferenceStr<T>
impl<S, T> PartialEq<Cow<'_, RiRelativeStr<S>>> for RiReferenceStr<T>
Sourceimpl<S, T> PartialEq<Cow<'_, RiRelativeStr<T>>> for &RiRelativeStr<S>
impl<S, T> PartialEq<Cow<'_, RiRelativeStr<T>>> for &RiRelativeStr<S>
Sourceimpl<S, T> PartialEq<RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<RiAbsoluteString<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<RiAbsoluteString<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<RiAbsoluteString<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialEq<RiAbsoluteString<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialEq<RiFragmentString<T>> for Cow<'_, RiFragmentStr<S>>
impl<S, T> PartialEq<RiFragmentString<T>> for Cow<'_, RiFragmentStr<S>>
Sourceimpl<S, T> PartialEq<RiQueryString<T>> for Cow<'_, RiQueryStr<S>>
impl<S, T> PartialEq<RiQueryString<T>> for Cow<'_, RiQueryStr<S>>
Sourceimpl<S, T> PartialEq<RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialEq<RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialEq<RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialEq<RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiReferenceStr<S>>
impl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiReferenceStr<S>>
Sourceimpl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialEq<RiReferenceString<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialEq<RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<RiRelativeString<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialEq<RiRelativeString<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialEq<RiRelativeString<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialEq<RiRelativeString<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<'a> PartialOrd<&'a ByteStr> for Cow<'a, [u8]>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, [u8]>
Sourceimpl<'a> PartialOrd<&'a ByteStr> for Cow<'a, ByteStr>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, ByteStr>
Sourceimpl<'a> PartialOrd<&'a ByteStr> for Cow<'a, str>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, str>
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, OsStr>
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, Path>
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
Sourceimpl PartialOrd<&RawStr> for Cow<'_, RawStr>
impl PartialOrd<&RawStr> for Cow<'_, RawStr>
Sourceimpl PartialOrd<&RawStr> for Cow<'_, str>
impl PartialOrd<&RawStr> for Cow<'_, str>
Sourceimpl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiAbsoluteStr<T>>
impl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiAbsoluteStr<T>>
Sourceimpl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiStr<T>>
impl<S, T> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, RiStr<T>>
Sourceimpl<S> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiAbsoluteStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiFragmentStr<S>> for Cow<'_, RiFragmentStr<T>>
impl<S, T> PartialOrd<&RiFragmentStr<S>> for Cow<'_, RiFragmentStr<T>>
Sourceimpl<S> PartialOrd<&RiFragmentStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiFragmentStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiQueryStr<S>> for Cow<'_, RiQueryStr<T>>
impl<S, T> PartialOrd<&RiQueryStr<S>> for Cow<'_, RiQueryStr<T>>
Sourceimpl<S> PartialOrd<&RiQueryStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiQueryStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiReferenceStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<&RiReferenceStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S> PartialOrd<&RiReferenceStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiReferenceStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiStr<S>>
impl<S, T> PartialOrd<&RiReferenceStr<T>> for Cow<'_, RiStr<S>>
Sourceimpl<S, T> PartialOrd<&RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<&RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialOrd<&RiRelativeStr<S>> for Cow<'_, RiRelativeStr<T>>
impl<S, T> PartialOrd<&RiRelativeStr<S>> for Cow<'_, RiRelativeStr<T>>
Sourceimpl<S> PartialOrd<&RiRelativeStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiRelativeStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<&RiStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialOrd<&RiStr<S>> for Cow<'_, RiStr<T>>
impl<S, T> PartialOrd<&RiStr<S>> for Cow<'_, RiStr<T>>
Sourceimpl<S> PartialOrd<&RiStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<&RiStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<&RiStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<&RiStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl PartialOrd<&UriTemplateStr> for Cow<'_, str>
impl PartialOrd<&UriTemplateStr> for Cow<'_, str>
Sourceimpl<'a, 'b> PartialOrd<&'b Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<&'b Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, OsStr>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, Path>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, Path>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, str>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, str>
Sourceimpl<'a> PartialOrd<ByteString> for Cow<'_, [u8]>
impl<'a> PartialOrd<ByteString> for Cow<'_, [u8]>
Sourceimpl<'a> PartialOrd<ByteString> for Cow<'_, ByteStr>
impl<'a> PartialOrd<ByteString> for Cow<'_, ByteStr>
Sourceimpl<'a> PartialOrd<ByteString> for Cow<'_, str>
impl<'a> PartialOrd<ByteString> for Cow<'_, str>
Sourceimpl PartialOrd<Cow<'_, RawStr>> for &RawStr
impl PartialOrd<Cow<'_, RawStr>> for &RawStr
Sourceimpl PartialOrd<Cow<'_, RawStr>> for RawStr
impl PartialOrd<Cow<'_, RawStr>> for RawStr
Sourceimpl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for &RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for &RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for &RiStr<T>
impl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for &RiStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for RiStr<T>
impl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<S>>> for RiStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<T>>> for &RiAbsoluteStr<S>
impl<S, T> PartialOrd<Cow<'_, RiAbsoluteStr<T>>> for &RiAbsoluteStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiFragmentStr<T>>> for &RiFragmentStr<S>
impl<S, T> PartialOrd<Cow<'_, RiFragmentStr<T>>> for &RiFragmentStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiQueryStr<T>>> for &RiQueryStr<S>
impl<S, T> PartialOrd<Cow<'_, RiQueryStr<T>>> for &RiQueryStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiAbsoluteStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiAbsoluteStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiReferenceStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiReferenceStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiRelativeStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiRelativeStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for &RiStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiAbsoluteStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiAbsoluteStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiRelativeStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiRelativeStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiStr<S>
impl<S, T> PartialOrd<Cow<'_, RiReferenceStr<T>>> for RiStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiRelativeStr<S>>> for &RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiRelativeStr<S>>> for &RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiRelativeStr<S>>> for RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiRelativeStr<S>>> for RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiRelativeStr<T>>> for &RiRelativeStr<S>
impl<S, T> PartialOrd<Cow<'_, RiRelativeStr<T>>> for &RiRelativeStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiStr<S>>> for &RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiStr<S>>> for &RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiStr<S>>> for RiReferenceStr<T>
impl<S, T> PartialOrd<Cow<'_, RiStr<S>>> for RiReferenceStr<T>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for &RiAbsoluteStr<S>
impl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for &RiAbsoluteStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for &RiStr<S>
impl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for &RiStr<S>
Sourceimpl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for RiAbsoluteStr<S>
impl<S, T> PartialOrd<Cow<'_, RiStr<T>>> for RiAbsoluteStr<S>
Sourceimpl PartialOrd<Cow<'_, str>> for &RawStr
impl PartialOrd<Cow<'_, str>> for &RawStr
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiAbsoluteStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiAbsoluteStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiFragmentStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiFragmentStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiQueryStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiQueryStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiReferenceStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiReferenceStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiRelativeStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiRelativeStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for &RiStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for &RiStr<S>where
S: Spec,
Sourceimpl PartialOrd<Cow<'_, str>> for &UriTemplateStr
impl PartialOrd<Cow<'_, str>> for &UriTemplateStr
Sourceimpl PartialOrd<Cow<'_, str>> for RawStr
impl PartialOrd<Cow<'_, str>> for RawStr
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiAbsoluteStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiAbsoluteStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiFragmentStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiFragmentStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiQueryStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiQueryStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiReferenceStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiReferenceStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiRelativeStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiRelativeStr<S>where
S: Spec,
Sourceimpl<S> PartialOrd<Cow<'_, str>> for RiStr<S>where
S: Spec,
impl<S> PartialOrd<Cow<'_, str>> for RiStr<S>where
S: Spec,
Sourceimpl PartialOrd<Cow<'_, str>> for UriTemplateStr
impl PartialOrd<Cow<'_, str>> for UriTemplateStr
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for &'b OsStr
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsStr
1.8.0 · Sourceimpl<'a> PartialOrd<Cow<'a, OsStr>> for Path
impl<'a> PartialOrd<Cow<'a, OsStr>> for Path
1.8.0 · Sourceimpl<'a> PartialOrd<Cow<'a, OsStr>> for PathBuf
impl<'a> PartialOrd<Cow<'a, OsStr>> for PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8Path
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b OsStr
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path
1.8.0 · Sourceimpl<'a> PartialOrd<Cow<'a, Path>> for OsStr
impl<'a> PartialOrd<Cow<'a, Path>> for OsStr
1.8.0 · Sourceimpl<'a> PartialOrd<Cow<'a, Path>> for Path
impl<'a> PartialOrd<Cow<'a, Path>> for Path
1.8.0 · Sourceimpl<'a> PartialOrd<Cow<'a, Path>> for PathBuf
impl<'a> PartialOrd<Cow<'a, Path>> for PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for &'b Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for &'b Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8Path
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, Path>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, Path>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, str>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, str>> for &'a Utf8Path
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsStr> for Cow<'a, OsStr>
1.8.0 · Sourceimpl<'a> PartialOrd<OsStr> for Cow<'a, Path>
impl<'a> PartialOrd<OsStr> for Cow<'a, Path>
1.8.0 · Sourceimpl<'a, 'b> PartialOrd<OsString> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsString> for Cow<'a, OsStr>
1.8.0 · Sourceimpl<'a> PartialOrd<OsString> for Cow<'a, Path>
impl<'a> PartialOrd<OsString> for Cow<'a, Path>
1.8.0 · Sourceimpl<'a> PartialOrd<Path> for Cow<'a, OsStr>
impl<'a> PartialOrd<Path> for Cow<'a, OsStr>
1.8.0 · Sourceimpl<'a> PartialOrd<Path> for Cow<'a, Path>
impl<'a> PartialOrd<Path> for Cow<'a, Path>
1.8.0 · Sourceimpl<'a> PartialOrd<PathBuf> for Cow<'a, OsStr>
impl<'a> PartialOrd<PathBuf> for Cow<'a, OsStr>
1.8.0 · Sourceimpl<'a> PartialOrd<PathBuf> for Cow<'a, Path>
impl<'a> PartialOrd<PathBuf> for Cow<'a, Path>
Sourceimpl PartialOrd<RawStr> for Cow<'_, RawStr>
impl PartialOrd<RawStr> for Cow<'_, RawStr>
Sourceimpl PartialOrd<RawStr> for Cow<'_, str>
impl PartialOrd<RawStr> for Cow<'_, str>
Sourceimpl<S, T> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, RiStr<T>>
impl<S, T> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, RiStr<T>>
Sourceimpl<S> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiAbsoluteStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiAbsoluteString<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiAbsoluteString<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S, T> PartialOrd<RiAbsoluteString<S>> for Cow<'_, RiStr<T>>
impl<S, T> PartialOrd<RiAbsoluteString<S>> for Cow<'_, RiStr<T>>
Sourceimpl<S> PartialOrd<RiAbsoluteString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiAbsoluteString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiAbsoluteString<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<RiAbsoluteString<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S> PartialOrd<RiFragmentStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiFragmentStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S> PartialOrd<RiFragmentString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiFragmentString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiFragmentString<T>> for Cow<'_, RiFragmentStr<S>>
impl<S, T> PartialOrd<RiFragmentString<T>> for Cow<'_, RiFragmentStr<S>>
Sourceimpl<S> PartialOrd<RiQueryStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiQueryStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S> PartialOrd<RiQueryString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiQueryString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiQueryString<T>> for Cow<'_, RiQueryStr<S>>
impl<S, T> PartialOrd<RiQueryString<T>> for Cow<'_, RiQueryStr<S>>
Sourceimpl<S> PartialOrd<RiReferenceStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiReferenceStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiStr<S>>
impl<S, T> PartialOrd<RiReferenceStr<T>> for Cow<'_, RiStr<S>>
Sourceimpl<S> PartialOrd<RiReferenceString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiReferenceString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiReferenceStr<S>>
impl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiReferenceStr<S>>
Sourceimpl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiStr<S>>
impl<S, T> PartialOrd<RiReferenceString<T>> for Cow<'_, RiStr<S>>
Sourceimpl<S, T> PartialOrd<RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiRelativeStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S> PartialOrd<RiRelativeStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiRelativeStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiRelativeString<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiRelativeString<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S> PartialOrd<RiRelativeString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiRelativeString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiRelativeString<T>> for Cow<'_, RiRelativeStr<S>>
impl<S, T> PartialOrd<RiRelativeString<T>> for Cow<'_, RiRelativeStr<S>>
Sourceimpl<S, T> PartialOrd<RiStr<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiStr<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S> PartialOrd<RiStr<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiStr<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiStr<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<RiStr<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialOrd<RiString<S>> for Cow<'_, RiReferenceStr<T>>
impl<S, T> PartialOrd<RiString<S>> for Cow<'_, RiReferenceStr<T>>
Sourceimpl<S> PartialOrd<RiString<S>> for Cow<'_, str>where
S: Spec,
impl<S> PartialOrd<RiString<S>> for Cow<'_, str>where
S: Spec,
Sourceimpl<S, T> PartialOrd<RiString<T>> for Cow<'_, RiAbsoluteStr<S>>
impl<S, T> PartialOrd<RiString<T>> for Cow<'_, RiAbsoluteStr<S>>
Sourceimpl<S, T> PartialOrd<RiString<T>> for Cow<'_, RiStr<S>>
impl<S, T> PartialOrd<RiString<T>> for Cow<'_, RiStr<S>>
Sourceimpl PartialOrd<UriTemplateStr> for Cow<'_, str>
impl PartialOrd<UriTemplateStr> for Cow<'_, str>
Sourceimpl PartialOrd<UriTemplateString> for Cow<'_, str>
impl PartialOrd<UriTemplateString> for Cow<'_, str>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, str>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, str>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, str>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, str>
1.0.0 · Sourceimpl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, B> PartialOrd for Cow<'a, B>
Sourceimpl<'a> Replacer for &'a Cow<'a, [u8]>
impl<'a> Replacer for &'a Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for &'a Cow<'a, str>
impl<'a> Replacer for &'a Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, [u8]>
impl<'a> Replacer for Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, str>
impl<'a> Replacer for Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<C> RequestConnection for Cow<'_, C>
impl<C> RequestConnection for Cow<'_, C>
Sourcetype Buf = <C as RequestConnection>::Buf
type Buf = <C as RequestConnection>::Buf
Sourcefn send_request_with_reply<R>(
&self,
bufs: &[IoSlice<'_>],
fds: Vec<OwnedFd>,
) -> Result<Cookie<'_, Cow<'_, C>, R>, ConnectionError>where
R: TryParse,
fn send_request_with_reply<R>(
&self,
bufs: &[IoSlice<'_>],
fds: Vec<OwnedFd>,
) -> Result<Cookie<'_, Cow<'_, C>, R>, ConnectionError>where
R: TryParse,
Sourcefn send_trait_request_with_reply<R>(
&self,
request: R,
) -> Result<Cookie<'_, Cow<'_, C>, <R as ReplyRequest>::Reply>, ConnectionError>where
R: ReplyRequest,
fn send_trait_request_with_reply<R>(
&self,
request: R,
) -> Result<Cookie<'_, Cow<'_, C>, <R as ReplyRequest>::Reply>, ConnectionError>where
R: ReplyRequest,
Sourcefn send_request_with_reply_with_fds<R>(
&self,
bufs: &[IoSlice<'_>],
fds: Vec<OwnedFd>,
) -> Result<CookieWithFds<'_, Cow<'_, C>, R>, ConnectionError>where
R: TryParseFd,
fn send_request_with_reply_with_fds<R>(
&self,
bufs: &[IoSlice<'_>],
fds: Vec<OwnedFd>,
) -> Result<CookieWithFds<'_, Cow<'_, C>, R>, ConnectionError>where
R: TryParseFd,
Sourcefn send_trait_request_with_reply_with_fds<R>(
&self,
request: R,
) -> Result<CookieWithFds<'_, Cow<'_, C>, <R as ReplyFDsRequest>::Reply>, ConnectionError>where
R: ReplyFDsRequest,
fn send_trait_request_with_reply_with_fds<R>(
&self,
request: R,
) -> Result<CookieWithFds<'_, Cow<'_, C>, <R as ReplyFDsRequest>::Reply>, ConnectionError>where
R: ReplyFDsRequest,
Sourcefn send_request_without_reply(
&self,
bufs: &[IoSlice<'_>],
fds: Vec<OwnedFd>,
) -> Result<VoidCookie<'_, Cow<'_, C>>, ConnectionError>
fn send_request_without_reply( &self, bufs: &[IoSlice<'_>], fds: Vec<OwnedFd>, ) -> Result<VoidCookie<'_, Cow<'_, C>>, ConnectionError>
Sourcefn send_trait_request_without_reply<R>(
&self,
request: R,
) -> Result<VoidCookie<'_, Cow<'_, C>>, ConnectionError>where
R: VoidRequest,
fn send_trait_request_without_reply<R>(
&self,
request: R,
) -> Result<VoidCookie<'_, Cow<'_, C>>, ConnectionError>where
R: VoidRequest,
Sourcefn discard_reply(&self, sequence: u64, kind: RequestKind, mode: DiscardMode)
fn discard_reply(&self, sequence: u64, kind: RequestKind, mode: DiscardMode)
Sourcefn prefetch_extension_information(
&self,
extension_name: &'static str,
) -> Result<(), ConnectionError>
fn prefetch_extension_information( &self, extension_name: &'static str, ) -> Result<(), ConnectionError>
Sourcefn extension_information(
&self,
extension_name: &'static str,
) -> Result<Option<ExtensionInformation>, ConnectionError>
fn extension_information( &self, extension_name: &'static str, ) -> Result<Option<ExtensionInformation>, ConnectionError>
Sourcefn wait_for_reply_or_error(
&self,
sequence: u64,
) -> Result<<Cow<'_, C> as RequestConnection>::Buf, ReplyError>
fn wait_for_reply_or_error( &self, sequence: u64, ) -> Result<<Cow<'_, C> as RequestConnection>::Buf, ReplyError>
Sourcefn wait_for_reply_or_raw_error(
&self,
sequence: u64,
) -> Result<ReplyOrError<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
fn wait_for_reply_or_raw_error( &self, sequence: u64, ) -> Result<ReplyOrError<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
Sourcefn wait_for_reply(
&self,
sequence: u64,
) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
fn wait_for_reply( &self, sequence: u64, ) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
Sourcefn wait_for_reply_with_fds(
&self,
sequence: u64,
) -> Result<(<Cow<'_, C> as RequestConnection>::Buf, Vec<OwnedFd>), ReplyError>
fn wait_for_reply_with_fds( &self, sequence: u64, ) -> Result<(<Cow<'_, C> as RequestConnection>::Buf, Vec<OwnedFd>), ReplyError>
Sourcefn wait_for_reply_with_fds_raw(
&self,
sequence: u64,
) -> Result<ReplyOrError<(<Cow<'_, C> as RequestConnection>::Buf, Vec<OwnedFd>), <Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
fn wait_for_reply_with_fds_raw( &self, sequence: u64, ) -> Result<ReplyOrError<(<Cow<'_, C> as RequestConnection>::Buf, Vec<OwnedFd>), <Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
Sourcefn check_for_error(&self, sequence: u64) -> Result<(), ReplyError>
fn check_for_error(&self, sequence: u64) -> Result<(), ReplyError>
Sourcefn check_for_raw_error(
&self,
sequence: u64,
) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
fn check_for_raw_error( &self, sequence: u64, ) -> Result<Option<<Cow<'_, C> as RequestConnection>::Buf>, ConnectionError>
Sourcefn prefetch_maximum_request_bytes(&self)
fn prefetch_maximum_request_bytes(&self)
Sourcefn maximum_request_bytes(&self) -> usize
fn maximum_request_bytes(&self) -> usize
Sourcefn parse_error(&self, error: &[u8]) -> Result<X11Error, ParseError>
fn parse_error(&self, error: &[u8]) -> Result<X11Error, ParseError>
Sourcefn parse_event(&self, event: &[u8]) -> Result<Event, ParseError>
fn parse_event(&self, event: &[u8]) -> Result<Event, ParseError>
Sourceimpl<'a, T> Serialize for Cow<'a, T>
impl<'a, T> Serialize for Cow<'a, T>
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<P> UriDisplay<P> for Cow<'_, str>where
P: Part,
Percent-encodes the raw string. Defers to str.
impl<P> UriDisplay<P> for Cow<'_, str>where
P: Part,
Percent-encodes the raw string. Defers to str.
Sourceimpl WriteTomlKey for Cow<'_, str>
impl WriteTomlKey for Cow<'_, str>
Sourceimpl WriteTomlValue for Cow<'_, str>
impl WriteTomlValue for Cow<'_, str>
Sourceimpl<'a, T> Writeable for Cow<'a, T>
impl<'a, T> Writeable for Cow<'a, T>
Sourcefn write_to<W>(&self, sink: &mut W) -> Result<(), Error>
fn write_to<W>(&self, sink: &mut W) -> Result<(), Error>
write_to_parts, and discards any
Part annotations.Sourcefn write_to_parts<W>(&self, sink: &mut W) -> Result<(), Error>where
W: PartsWrite + ?Sized,
fn write_to_parts<W>(&self, sink: &mut W) -> Result<(), Error>where
W: PartsWrite + ?Sized,
Part annotations to the given sink. Errors from the
sink are bubbled up. The default implementation delegates to write_to,
and doesn’t produce any Part annotations.Sourcefn writeable_length_hint(&self) -> LengthHint
fn writeable_length_hint(&self) -> LengthHint
Sourceimpl<'a, T> Yokeable<'a> for Cow<'static, T>
impl<'a, T> Yokeable<'a> for Cow<'static, T>
Sourcetype Output = Cow<'a, T>
type Output = Cow<'a, T>
Self with the 'static replaced with 'a, i.e. Self<'a>Sourcefn transform_owned(self) -> Cow<'a, T>
fn transform_owned(self) -> Cow<'a, T>
impl<T> DerefPure for Cow<'_, [T]>where
T: Clone,
impl<T> DerefPure for Cow<'_, T>where
T: Clone,
impl DerefPure for Cow<'_, str>
impl<B> Eq for Cow<'_, B>