pub enum TomlEditItem {
None,
Value(Value),
Table(Table),
ArrayOfTables(ArrayOfTables),
}Expand description
Type representing either a value, a table, an array of tables, or none.
Variants
None
Type representing none.
Value(Value)
Type representing value.
Table(Table)
Type representing table.
ArrayOfTables(ArrayOfTables)
Type representing array of tables.
Implementations
Sourceimpl Item
Downcasting
impl Item
Downcasting
Sourcepub fn get<I>(&self, index: I) -> Option<&Item>where
I: Index,
pub fn get<I>(&self, index: I) -> Option<&Item>where
I: Index,
Index into a TOML array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.
Returns None if:
- The type of
selfdoes not match the type of the index, for example if the index is a string andselfis an array or a number. - The given key does not exist in the map or the given index is not within the bounds of the array.
Sourcepub fn get_mut<I>(&mut self, index: I) -> Option<&mut Item>where
I: Index,
pub fn get_mut<I>(&mut self, index: I) -> Option<&mut Item>where
I: Index,
Mutably index into a TOML array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.
Returns None if:
- The type of
selfdoes not match the type of the index, for example if the index is a string andselfis an array or a number. - The given key does not exist in the map or the given index is not within the bounds of the array.
Sourcepub fn as_table(&self) -> Option<&Table>
pub fn as_table(&self) -> Option<&Table>
Casts self to Table
To operate on both Tables and InlineTables, see Item::as_table_like
Sourcepub fn as_array_of_tables(&self) -> Option<&ArrayOfTables>
pub fn as_array_of_tables(&self) -> Option<&ArrayOfTables>
Casts self to ArrayOfTables
Sourcepub fn as_value_mut(&mut self) -> Option<&mut Value>
pub fn as_value_mut(&mut self) -> Option<&mut Value>
Casts self to mutable Value.
Sourcepub fn as_table_mut(&mut self) -> Option<&mut Table>
pub fn as_table_mut(&mut self) -> Option<&mut Table>
Casts self to mutable Table
To operate on both Tables and InlineTables, see Item::as_table_like_mut
Sourcepub fn as_array_of_tables_mut(&mut self) -> Option<&mut ArrayOfTables>
pub fn as_array_of_tables_mut(&mut self) -> Option<&mut ArrayOfTables>
Casts self to mutable ArrayOfTables
Sourcepub fn make_value(&mut self)
pub fn make_value(&mut self)
In-place convert to a value
Sourcepub fn into_table(self) -> Result<Table, Item>
pub fn into_table(self) -> Result<Table, Item>
Casts self to Table
This does not include InlineTables
Sourcepub fn into_array_of_tables(self) -> Result<ArrayOfTables, Item>
pub fn into_array_of_tables(self) -> Result<ArrayOfTables, Item>
Casts self to ArrayOfTables
Sourcepub fn is_table(&self) -> bool
pub fn is_table(&self) -> bool
Returns true if self is a Table
To operate on both Tables and InlineTables, see Item::is_table_like
Sourcepub fn is_array_of_tables(&self) -> bool
pub fn is_array_of_tables(&self) -> bool
Returns true if self is an ArrayOfTables
Sourcepub fn as_integer(&self) -> Option<i64>
pub fn as_integer(&self) -> Option<i64>
Casts self to integer.
Sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if self is an integer.
Sourcepub fn as_datetime(&self) -> Option<&Datetime>
pub fn as_datetime(&self) -> Option<&Datetime>
Casts self to date-time.
Sourcepub fn is_datetime(&self) -> bool
pub fn is_datetime(&self) -> bool
Returns true if self is a date-time.
Sourcepub fn as_array_mut(&mut self) -> Option<&mut Array>
pub fn as_array_mut(&mut self) -> Option<&mut Array>
Casts self to mutable array.
Sourcepub fn as_inline_table(&self) -> Option<&InlineTable>
pub fn as_inline_table(&self) -> Option<&InlineTable>
Casts self to inline table.
Sourcepub fn as_inline_table_mut(&mut self) -> Option<&mut InlineTable>
pub fn as_inline_table_mut(&mut self) -> Option<&mut InlineTable>
Casts self to mutable inline table.
Sourcepub fn is_inline_table(&self) -> bool
pub fn is_inline_table(&self) -> bool
Returns true if self is an inline table.
Sourcepub fn as_table_like(&self) -> Option<&dyn TableLike>
pub fn as_table_like(&self) -> Option<&dyn TableLike>
Casts self to either a table or an inline table.
Sourcepub fn as_table_like_mut(&mut self) -> Option<&mut dyn TableLike>
pub fn as_table_like_mut(&mut self) -> Option<&mut dyn TableLike>
Casts self to either a table or an inline table.
Sourcepub fn is_table_like(&self) -> bool
pub fn is_table_like(&self) -> bool
Returns true if self is either a table, or an inline table.