pub trait AxisName {
// Required method
fn axis_name(&self) -> Cow<'_, str>;
}Expand description
A trait that describes the name of an axis. Implementations usually associate one distinct axis name string per enum variant.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".